==> haskell-reducers-3.12.5-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-8Wz97JxRjCN4ApOxDPjs3A
key:                  reducers-3.12.5-8Wz97JxRjCN4ApOxDPjs3A
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  fb354e67e0e6cef6d76d4021e3ae9ace
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-8Wz97JxRjCN4ApOxDPjs3A
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.5.0-LqJf8RwZyCzH9Wcvq2jau
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    semigroupoids-6.0.1-4MzfMO8TUru5bIlkk6eiWh text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.5-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-E8pFbYAQn7n6LUHraAJ9j8
key:                  reducers-3.12.5-E8pFbYAQn7n6LUHraAJ9j8
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  c919663b36f98d70a4d1e0cdbcb8568e
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-E8pFbYAQn7n6LUHraAJ9j8
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.5.0-LqJf8RwZyCzH9Wcvq2jau
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    semigroupoids-6.0.1-Jr4qwSJRHF330Efi7HW1er text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
